require_relative "../../../test_helper"

class DTest < MTest
  def test_d
    assert_equal 1, 1
  end
end
